import { Component, ViewChild } from '@angular/core';
import { Nav, Platform } from 'ionic-angular';
import { SplashScreen } from '@ionic-native/splash-screen';
import { Storage } from '@ionic/storage';
import { Device } from '@ionic-native/device';

import { LoginPage } from '../pages/login/login';
import { StreamPage } from '../pages/stream/stream';
import { SettingsPage } from '../pages/settings/settings';
import { AboutPage } from '../pages/about/about';
import { ProfilePage } from '../pages/profile/profile';
import { pnutauth } from '../pages/login/pnutauth';

import { IUser } from '../models/IUser';

import * as pnut from 'pnut-butter';

@Component({
  templateUrl: 'app.html'
})
export class MyApp {
  @ViewChild(Nav) nav: Nav;

  rootPage: any = StreamPage;
  pages: Array<{title: string, icon: string, component: any, params: Object}>;
  profile: IUser;

  constructor(public platform: Platform, public splashScreen: SplashScreen,
    private storage: Storage, private device: Device) {
    this.initializeApp();

    // used for an example of ngFor and navigation
    this.pages = [
      { title: 'Timeline', icon: 'home', component: StreamPage, params: {stream: 'personal'} },
      { title: 'Mentions', icon: 'at', component: StreamPage, params: {stream: 'mentions'} },
      { title: 'Global', icon: 'globe', component: StreamPage, params: {stream: 'global'} },
      { title: 'Bookmarks', icon: 'bookmarks', component: StreamPage, params: {stream: 'bookmarks'} },
      { title: 'Profile', icon: 'person', component: ProfilePage, params: {}},
      { title: 'Settings', icon: 'settings', component: SettingsPage, params: {}},
      { title: 'About', icon: 'information-circle', component: AboutPage, params: {}},
      { title: 'Logout', icon: 'exit', component: {}, params: {}},
    ];

  }

  initializeApp() {
    console.log('--- initializeApp ---');

    this.platform.ready().then(() => {
      // Okay, so the platform is ready and our plugins are available.
      // Here you can do any higher level native things you might need.

      this.storage.get('timeline').then((val) => {
        if (val.length > 1) {
          this.initialPage(val);
        } else {
          console.log('ERR WHUT?');
        }
      }).catch(err => {
        this.initialPage('personal');
      });

      this.splashScreen.hide();
      // console.log('---');
      // console.log(this.device.platform);
      // console.log('---');
    });
  }

  initialPage(timeline) {
    this.storage.get('token').then((val) => {
      if (val.length > 1) {
        pnut.token = val;

        this.storage.get('scope').then((sval) => {
          if (JSON.stringify(sval) !== JSON.stringify(pnutauth.scope)) {
            this.nav.setRoot(LoginPage, {});
          } else {
            this.nav.setRoot(StreamPage, {stream: timeline});
          }
          // this.nav.setRoot(StreamPage, {stream: timeline});
        }).catch(err => {
          this.nav.setRoot(LoginPage, {});
        });
        // this.nav.setRoot(StreamPage, {stream: timeline});
      }
    }).catch(err => {
      console.log('ERROR: ' + err);
      this.nav.setRoot(LoginPage, {});
    });
  }

  async openPage(page) {
    // Reset the content nav to have just this page
    // we wouldn't want the back button to show in this scenario
    if (page.title === 'Logout') {
      // this.storage.remove('token');
      this.storage.clear();
      this.nav.setRoot(LoginPage, {});
    } else if (page.title === 'Settings' || page.title === 'About') {
      this.nav.push(page.component, page.params);
    } else if (page.title === 'Profile') {
      await pnut.user('me').then(res => {
        this.profile = res.data as IUser;
      });
      page.params = {user: this.profile, me: this.profile.username};
      this.nav.push(page.component, page.params);
    } else {
      this.nav.setRoot(page.component, page.params);
    }
  }

}
