import { Component } from '@angular/core';
import { NavController, NavParams } from 'ionic-angular';
import { HttpClient, HttpParams, HttpHeaders } from '@angular/common/http';
import { Storage } from '@ionic/storage';
import { StreamPage } from '../stream/stream';
import { pnutauth } from './pnutauth';

import * as pnut from 'pnut-butter';


@Component({
  selector: 'page-login',
  templateUrl: 'login.html',
})
export class LoginPage {

  private username: string;
  private password: string;

  constructor(public navCtrl: NavController, public navParams: NavParams, 
    private storage: Storage, private http: HttpClient) {

  }

  login() {

    interface LoginResponse {
      access_token: string;
    }

    let headers = new HttpHeaders()
      .set('Content-Type', 'application/x-www-form-urlencoded');
    
    let params = new HttpParams()
      .set('client_id', pnutauth.clientId)
      .set('password_grant_secret', pnutauth.clientSecret)
      .set('username', this.username)
      .set('password', this.password)
      .set('grant_type', 'password')
      .set('scope', pnutauth.scope);

    this.http.post<LoginResponse>(pnutauth.url, params, {headers: headers}).subscribe(res => {
      console.log('authorized');
      this.storage.set('scope', pnutauth.scope);
      this.storage.set('token', res.access_token);
      pnut.token = res.access_token;
      this.navCtrl.setRoot(StreamPage, {stream: "personal"});
    }, err => {
      console.log("error: " + JSON.stringify(err));
    });

  }

}
